==> ispack-0.1.tar.gz: ispack-0.1/sample/2D-plane/model2d.f <==
***********************************************************************
*     model2d.f: n2packȤä2ȯ򤯥ץ
*
*                                                    96/10/27 K.Ishioka
***********************************************************************
      IMPLICIT REAL*8(A-H,O-Z)

* ѥ᥿ 

      PARAMETER(LM=63,KM=63)    !ȿ(aliasingȤäƤʤ)
*      PARAMETER(LM=42,KM=42)    !ȿ(aliasingȤ)
      PARAMETER(N=(2*LM+1)*(2*KM+1)) !ڥȥѿ礭
      DIMENSION Z(N)            !٤Υڥȥ뷸
      DIMENSION W(N,3)          !Runge-KuttaˡΤκΰ
      EXTERNAL SBGDZL,SBGDZN    !Runge-KuttaˡƤӽФ֥롼

      NSTEP=100                 !ȯŸ륹ƥå׿
      H=1D0                     !եåɽΤλֳִ
      M=3                       !Runge-KuttaǤΥƥåʬ

      NV=5                      !ⳬǴΥץ饷γ
      DNU=1D-17                 !ⳬǴ
      DELTAT=H/M                !Runge-Kuttaλֹ

* 

      CALL SBINIT(NV,DNU,DELTAT)
      CALL SBINIZ(Z)

* ȯŸӥեåɽ

      T=0                       !Tϻɽѿ
      CALL SBGRPH(T,Z)

      DO ISTEP=1,NSTEP
        CALL TDRKNU(N,M,H,T,Z,W,SBGDZL,SBGDZN)
        CALL SBGRPH(T,Z)
      END DO

* λ

      CALL SBCLOS

      END
***********************************************************************
*     ʬɬפʼνޤȤ᤿֥롼ѥå
*----------------------------------------------------------------------
*     ѥåν򤹤륵֥롼
*----------------------------------------------------------------------
      SUBROUTINE SBINIT(NV,DNU,DELTAT)

      IMPLICIT REAL*8(A-H,O-Z)
      CHARACTER CTIME*5
      PARAMETER(JM=128,IM=128)    !ʻ(JM: y, IM: x)
      PARAMETER(LM=63,KM=63)    !ȿ(aliasingȤäƤʤ)
*      PARAMETER(LM=42,KM=42)    !ȿ(aliasingȤ)
      DIMENSION Z(-LM:LM,-KM:KM) !٤Υڥȥ뷸
      DIMENSION DZ(-LM:LM,-KM:KM) !Υڥȥ뷸
      DIMENSION WS(-LM:LM,-KM:KM) !ΰ
      DIMENSION WG(0:JM-1,0:IM-1,3) !ΰ
      DIMENSION ITJ(5),TJ(JM*2),ITI(5),TI(IM*2) !N2PACKǻȤ
      DIMENSION DL(-LM:LM,-KM:KM) !Ǵ̤Τ˻Ȥ
      REAL RG(0:IM,0:JM)        !եå˻Ȥ
      REAL DLEV,TLEV1,TLEV2     !եå˻Ȥѿ
      SAVE

* Ϳ줿, SBGDZNǻȤDL(Ǵˤ븺̤Ϳ)
* ꤹ. ʤ, SBGDZNRunge-KuttaǸƤӽФ뤬, κ,
* DT=DELTAT/2ǸƤӽФ뤫, θ, DLϰʲΤ
* Ǥ.

      DO K=-KM,KM
        DO L=-LM,LM
          DL(L,K)=EXP(-DNU*DELTAT/2*(1D0*(K*K+L*L))**NV)
        END DO
      END DO

* N2PACKν

      CALL N2INIT(JM,IM,ITJ,TJ,ITI,TI)

* եåν

      CALL SWPSET('IWIDTH',  400)
      CALL SWPSET('IHEIGHT', 400)
      CALL SWPSET('LWAIT',.FALSE.)
      CALL SWPSET('LALT',.TRUE.)
      CALL SGPSET('LCORNER',.FALSE.)

      CALL GROPN(1)
      CALL UZPSET('INNER',-1)
      CALL SLRAT(1.0,1.0)
      CALL GLPSET('LMISS',.TRUE.)
      CALL SGPSET('LCNTL',.TRUE.)
      CALL SLRAT(1.0,1.0)
      CALL UDGCLA(0.0,1.0,0.1)

      IPAT0=25
      DLEV=0.05
      NLEV=20
      IDLEV=3

      CALL UESTLV(999.0,0.0,IPAT0*1000+999)
      DO I=1,NLEV-1
        IPAT=(IPAT0+I*IDLEV)*1000+999
        TLEV1=(I-1)*DLEV
        TLEV2=I*DLEV
        CALL UESTLV(TLEV1,TLEV2,IPAT)
      END DO
      IPAT=(IPAT0+NLEV*IDLEV)*1000+999
      CALL UESTLV(TLEV2,999.0,IPAT)

      RETURN
*----------------------------------------------------------------------
*     ٤Υڥȥ뷸(Z)ν
*----------------------------------------------------------------------
      ENTRY SBINIZ(Z)

* Ǥ, 2ĤΥ󷿤α뱲ʬۤʻͿ, 
* N2G2SAȤäƥڥȥ뷸Ѵ, Zνͤ
* Ƥ

      X1=0.4D0
      Y1=0.4D0
      X2=0.6D0
      Y2=0.6D0
      SIGMA=0.05D0

      DO I=0,IM-1
        X=1D0*I/IM
        DO J=0,JM-1
          Y=1D0*J/JM
          WG(J,I,1)= EXP(-((X-X1)**2+(Y-Y1)**2)/(2*SIGMA**2))
     &              +EXP(-((X-X2)**2+(Y-Y2)**2)/(2*SIGMA**2))
        END DO
      END DO

      CALL N2G2SA(LM,KM,JM,IM,WG,Z,WG(0,0,3),ITJ,TJ,ITI,TI)

      Z(0,0)=0                  !٤ʿѤ0ǤʤФʤʤ

      RETURN
*----------------------------------------------------------------------
*     (T)ӱ٤Υڥȥ뷸(Z)ϤȤ, Υ
*     ȥ뷸(DZ)륵֥롼(Runge-KuttaǻȤ)
*----------------------------------------------------------------------
      ENTRY SBGDZN(T,Z,DZ)

      CALL N2AJBS(LM,KM,JM,IM,Z,DZ,WS,WG,ITJ,TJ,ITI,TI)

      RETURN
*----------------------------------------------------------------------
*     (T)ӻֹ(DT)ϤȤ, (Ǵ)ˤZ
*     TT+DTˤȯŸ򤯥֥롼(Runge-KuttaǻȤ)
*----------------------------------------------------------------------
      ENTRY SBGDZL(T,DT,Z)

      DO K=-KM,KM
        DO L=-LM,LM
          Z(L,K)=DL(L,K)*Z(L,K)
        END DO
      END DO

      RETURN
*----------------------------------------------------------------------
*     Zб뱲پ򥰥եåɽ.
*----------------------------------------------------------------------
      ENTRY SBGRPH(T,Z)

      WRITE(CTIME,'(F5.1)') T

      CALL N2S2GA(LM,KM,JM,IM,Z,WG,WG(0,0,3),ITJ,TJ,ITI,TI)

      DO I=0,IM-1
        DO J=0,JM-1
          RG(I,J)=WG(J,I,1)
        END DO
      END DO

      DO J=0,JM-1
        RG(IM,J)=RG(0,J)
      END DO
      DO I=0,IM-1
        RG(I,JM)=RG(I,0)
      END DO
      RG(IM,JM)=RG(0,0)

      CALL GRFRM
      CALL SGSVPT(0.15,0.9,0.15,0.9)
      CALL SGSWND(0.0,1.0,0.0,1.0)
      CALL SGSTRN(1)
      CALL SGSTRF

      CALL UETONE(RG,IM+1,IM+1,JM+1)
*      CALL UDCNTR(RG,IM+1,IM+1,JM+1)
      CALL USDAXS
      CALL UXSTTL('T','T='//CTIME,1.0)
*      CALL GRFRM

      RETURN
*----------------------------------------------------------------------
*     λ
*----------------------------------------------------------------------
      ENTRY SBCLOS

      CALL GRCLS

      END

==> ispack-0.91.tar.gz: ispack-0.91/sample/2D-plane/model2d.f <==
************************************************************************
* ISPACK FORTRAN SUBROUTINE LIBRARY FOR SCIENTIFIC COMPUTING
* Copyright (C) 1998--2009 Keiichi Ishioka <ishioka@gfd-dennou.org>
*
* This library is free software; you can redistribute it and/or
* modify it under the terms of the GNU Lesser General Public
* License as published by the Free Software Foundation; either
* version 2.1 of the License, or (at your option) any later version.
*
* This library is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
* Lesser General Public License for more details.
* 
* You should have received a copy of the GNU Lesser General Public
* License along with this library; if not, write to the Free Software
* Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
* 02110-1301 USA.
************************************************************************
***********************************************************************
*     model2d.f: n2packȤä2ȯ򤯥ץ
*
*                                                    96/10/27 K.Ishioka
***********************************************************************
      IMPLICIT REAL*8(A-H,O-Z)

* ѥ᥿ 

      PARAMETER(LM=63,KM=63)    !ȿ(aliasingȤäƤʤ)
*      PARAMETER(LM=42,KM=42)    !ȿ(aliasingȤ)
      PARAMETER(N=(2*LM+1)*(2*KM+1)) !ڥȥѿ礭
      DIMENSION Z(N)            !٤Υڥȥ뷸
      DIMENSION W(N,3)          !Runge-KuttaˡΤκΰ
      EXTERNAL SBGDZL,SBGDZN    !Runge-KuttaˡƤӽФ֥롼

      NSTEP=100                 !ȯŸ륹ƥå׿
      H=1D0                     !եåɽΤλֳִ
      M=3                       !Runge-KuttaǤΥƥåʬ

      NV=5                      !ⳬǴΥץ饷γ
      DNU=1D-17                 !ⳬǴ
      DELTAT=H/M                !Runge-Kuttaλֹ

* 

      CALL SBINIT(NV,DNU,DELTAT)
      CALL SBINIZ(Z)

* ȯŸӥեåɽ

      T=0                       !Tϻɽѿ
      CALL SBGRPH(T,Z)

      DO ISTEP=1,NSTEP
        CALL TDRKNU(N,M,H,T,Z,W,SBGDZL,SBGDZN)
        CALL SBGRPH(T,Z)
      END DO

* λ

      CALL SBCLOS

      END
***********************************************************************
*     ʬɬפʼνޤȤ᤿֥롼ѥå
*----------------------------------------------------------------------
*     ѥåν򤹤륵֥롼
*----------------------------------------------------------------------
      SUBROUTINE SBINIT(NV,DNU,DELTAT)

      IMPLICIT REAL*8(A-H,O-Z)
      CHARACTER CTIME*5
      PARAMETER(JM=128,IM=128)    !ʻ(JM: y, IM: x)
      PARAMETER(LM=63,KM=63)    !ȿ(aliasingȤäƤʤ)
*      PARAMETER(LM=42,KM=42)    !ȿ(aliasingȤ)
      DIMENSION Z(-LM:LM,-KM:KM) !٤Υڥȥ뷸
      DIMENSION DZ(-LM:LM,-KM:KM) !Υڥȥ뷸
      DIMENSION WS(-LM:LM,-KM:KM) !ΰ
      DIMENSION WG(0:JM-1,0:IM-1,3) !ΰ
      DIMENSION ITJ(5),TJ(JM*2),ITI(5),TI(IM*2) !N2PACKǻȤ
      DIMENSION DL(-LM:LM,-KM:KM) !Ǵ̤Τ˻Ȥ
      REAL RG(0:IM,0:JM)        !եå˻Ȥ
      REAL DLEV,TLEV1,TLEV2     !եå˻Ȥѿ
      SAVE

* Ϳ줿, SBGDZNǻȤDL(Ǵˤ븺̤Ϳ)
* ꤹ. ʤ, SBGDZNRunge-KuttaǸƤӽФ뤬, κ,
* DT=DELTAT/2ǸƤӽФ뤫, θ, DLϰʲΤ
* Ǥ.

      DO K=-KM,KM
        DO L=-LM,LM
          DL(L,K)=EXP(-DNU*DELTAT/2*(1D0*(K*K+L*L))**NV)
        END DO
      END DO

* N2PACKν

      CALL N2INIT(JM,IM,ITJ,TJ,ITI,TI)

* եåν

      CALL SWISET('IWIDTH',  400)
      CALL SWISET('IHEIGHT', 400)
      CALL SWLSET('LWAIT',.FALSE.)
      CALL SWLSET('LALT',.TRUE.)
      CALL SGLSET('LCORNER',.FALSE.)

      CALL GROPN(1)
      CALL UZPSET('INNER',-1)
      CALL SLRAT(1.0,1.0)
      CALL GLPSET('LMISS',.TRUE.)
      CALL SGPSET('LCNTL',.TRUE.)
      CALL SLRAT(1.0,1.0)
      CALL UDGCLA(0.0,1.0,0.1)

      IPAT0=25
      DLEV=0.05
      NLEV=20
      IDLEV=3

      CALL UESTLV(999.0,0.0,IPAT0*1000+999)
      DO I=1,NLEV-1
        IPAT=(IPAT0+I*IDLEV)*1000+999
        TLEV1=(I-1)*DLEV
        TLEV2=I*DLEV
        CALL UESTLV(TLEV1,TLEV2,IPAT)
      END DO
      IPAT=(IPAT0+NLEV*IDLEV)*1000+999
      CALL UESTLV(TLEV2,999.0,IPAT)

      RETURN
*----------------------------------------------------------------------
*     ٤Υڥȥ뷸(Z)ν
*----------------------------------------------------------------------
      ENTRY SBINIZ(Z)

* Ǥ, 2ĤΥ󷿤α뱲ʬۤʻͿ, 
* N2G2SAȤäƥڥȥ뷸Ѵ, Zνͤ
* Ƥ

      X1=0.4D0
      Y1=0.4D0
      X2=0.6D0
      Y2=0.6D0
      SIGMA=0.05D0

      DO I=0,IM-1
        X=1D0*I/IM
        DO J=0,JM-1
          Y=1D0*J/JM
          WG(J,I,1)= EXP(-((X-X1)**2+(Y-Y1)**2)/(2*SIGMA**2))
     &              +EXP(-((X-X2)**2+(Y-Y2)**2)/(2*SIGMA**2))
        END DO
      END DO

      CALL N2G2SA(LM,KM,JM,IM,WG,Z,WG(0,0,3),ITJ,TJ,ITI,TI)

      Z(0,0)=0                  !٤ʿѤ0ǤʤФʤʤ

      RETURN
*----------------------------------------------------------------------
*     (T)ӱ٤Υڥȥ뷸(Z)ϤȤ, Υ
*     ȥ뷸(DZ)륵֥롼(Runge-KuttaǻȤ)
*----------------------------------------------------------------------
      ENTRY SBGDZN(T,Z,DZ)

      CALL N2AJBS(LM,KM,JM,IM,Z,DZ,WS,WG,ITJ,TJ,ITI,TI)

      RETURN
*----------------------------------------------------------------------
*     (T)ӻֹ(DT)ϤȤ, (Ǵ)ˤZ
*     TT+DTˤȯŸ򤯥֥롼(Runge-KuttaǻȤ)
*----------------------------------------------------------------------
      ENTRY SBGDZL(T,DT,Z)

      DO K=-KM,KM
        DO L=-LM,LM
          Z(L,K)=DL(L,K)*Z(L,K)
        END DO
      END DO

      RETURN
*----------------------------------------------------------------------
*     Zб뱲پ򥰥եåɽ.
*----------------------------------------------------------------------
      ENTRY SBGRPH(T,Z)

      WRITE(CTIME,'(F5.1)') T

      CALL N2S2GA(LM,KM,JM,IM,Z,WG,WG(0,0,3),ITJ,TJ,ITI,TI)

      DO I=0,IM-1
        DO J=0,JM-1
          RG(I,J)=WG(J,I,1)
        END DO
      END DO

      DO J=0,JM-1
        RG(IM,J)=RG(0,J)
      END DO
      DO I=0,IM-1
        RG(I,JM)=RG(I,0)
      END DO
      RG(IM,JM)=RG(0,0)

      CALL GRFRM
      CALL SGSVPT(0.15,0.9,0.15,0.9)
      CALL SGSWND(0.0,1.0,0.0,1.0)
      CALL SGSTRN(1)
      CALL SGSTRF

      CALL UETONE(RG,IM+1,IM+1,JM+1)
*      CALL UDCNTR(RG,IM+1,IM+1,JM+1)
      CALL USDAXS
      CALL UXSTTL('T','T='//CTIME,1.0)
*      CALL GRFRM

      RETURN
*----------------------------------------------------------------------
*     λ
*----------------------------------------------------------------------
      ENTRY SBCLOS

      CALL GRCLS

      END
